/*
 * Copyright (C) 1994, Silicon Graphics, Inc.
 * All Rights Reserved.
 *
 * This is UNPUBLISHED PROPRIETARY SOURCE CODE of Silicon Graphics, Inc.;
 * the contents of this file may not be disclosed to third parties, copied or
 * duplicated in any form, in whole or in part, without the prior written
 * permission of Silicon Graphics, Inc.
 *
 * RESTRICTED RIGHTS LEGEND:
 * Use, duplication or disclosure by the Government is subject to restrictions
 * as set forth in subdivision (c)(1)(ii) of the Rights in Technical Data
 * and Computer Software clause at DFARS 252.227-7013, and/or in similar or
 * successor clauses in the FAR, DOD or NASA FAR Supplement. Unpublished -
 * rights reserved under the Copyright Laws of the United States.
 */
#include <stdio.h>
#include <fcntl.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <signal.h>
#include "rap.h"    
/*	
 *	record.c
 *
 *	This program plays song from a previuosly recorded file
 *	using RAP-10 board. 
 *
 */

#define    BUF_SIZE    4096
#define    FILE_HDR    "RAP-10 WAVE FILE"
#define    RAP_FILE    "/dev/rap"
#define    MAX_BUF     10 
#define    FOREVER     for(;;)

uchar_t    buf[BUF_SIZE];
uchar_t    *fname;
void       endProg( int );

main (int argc, char **argv)
{

	register int	fd, rapfd, bytes;

	if ( argc <= 1 ) {
		printf ("play: Usage: play <file_name>\n");
		exit(0);
	}

	fname = argv[1];
        printf ("play: opening file %s\n", fname); 
        fd = open (fname, O_RDONLY);
        if ( fd == -1 ) {
                printf ("play: Cannot create file, errno = %d\n", errno);
                close(rapfd);
                exit(0);
        }

        printf ("play: Checking RAP-10 File ID\n"); 
        if ( read(fd, buf, strlen(FILE_HDR)) <= 0 ) {
                printf ("play: Could not read the file ID, errno = %d\n",
                errno);
                close(fd);
                exit(0);
        }
	if ( strcmp(buf, FILE_HDR) ) {
		printf ("play: File is not a RAP file\n");
		close(fd);
		exit(0);
	}

	printf ("play: opening RAP card\n");
	rapfd = open (RAP_FILE, O_WRONLY);
	if ( rapfd <= 0 ) {
		printf ("play: Cannot open RAP card, errno = %d\n",
		errno);
		exit(0);
	}


	printf ("play: Playing ..please wait\n");      

	/*   ignore Interrupt   */
	sigset (SIGINT, SIG_IGN ); 

        FOREVER {          
  	        bytes = read(fd, buf, BUF_SIZE);  
		if ( bytes < 0 ) {
			printf ("play: error reading data, errno = %d",
				errno);
			close(fd);
			close(rapfd);
			exit(0);
		}

		if ( bytes == 0 )
			break;

		bytes = write(rapfd, buf, BUF_SIZE);
		if ( bytes <= 0 ) {
			printf ("play: Cannot read from RAP, errno = %d\n",
			errno);
			close (rapfd);
			close (fd);
			exit(0);
		}

	}
	printf ("play: waiting for Play to End\n");
	if ( ioctl (rapfd, RAPIOCTL_END_PLAY) ) {
		   printf ("play: Ioctl error %d", errno );
	}
	else printf ("play: Song succesfully played\n");
	close(rapfd);
	close (fd);

}

